"""Flreloadlast module."""
# -*- coding: utf-8 -*-
from pineboolib.qsa import qsa
import os


class FormInternalObj(qsa.FormDBWidget):
    """FormInternalObj class."""

    def init(self) -> None:
        """Init function."""
        pass

    def main(self) -> None:
        """Entry function."""
        util = qsa.FLUtil()
        setting = "scripts/sys/modLastModule_%s" % qsa.sys.nameBD()
        last_module = util.readSettingEntry(setting)
        if not last_module:
            last_module = qsa.FileDialog.getOpenFileName(
                util.translate("scripts", "Módulo a cargar (*.mod)"),
                util.translate("scripts", "Módulo a cargar"),
            )
            if not last_module:
                return
            util.writeSettingEntry(setting, last_module)

        qsa.sys.processEvents()
        self.load_module(last_module)
        qsa.sys.reinit()

    def load_module(self, nombre_fichero: str) -> bool:
        """Load modules."""
        util = qsa.FLUtil()
        fichero = qsa.File(nombre_fichero, "iso-8859-15")
        modulo = None
        descripcion = None
        area = None
        area_description = None
        version = None
        icon_name = None
        # versionMinimaFL = None
        dependencias = qsa.Array()
        fichero.open(qsa.File.ReadOnly)
        file_ = fichero.read()
        module_xml = qsa.FLDomDocument()
        if module_xml.setContent(file_):
            module_node = module_xml.namedItem("MODULE")
            if module_node is None:
                qsa.MessageBox.critical(
                    util.translate("scripts", "Error en la carga del fichero xml .mod"),
                    qsa.MessageBox.Ok,
                    qsa.MessageBox.NoButton,
                )
            modulo = module_node.namedItem("name").toElement().text()
            descripcion = module_node.namedItem("alias").toElement().text()
            area = module_node.namedItem("area").toElement().text()
            area_description = module_node.namedItem("areaname").toElement().text()
            version = module_node.namedItem("version").toElement().text()
            icon_name = module_node.namedItem("icon").toElement().text()
            # if module_node.namedItem(u"flversion"):
            #    versionMinimaFL = module_node.namedItem(u"flversion").toElement().text()
            if module_node.namedItem("dependencies") is not None:
                depend_node = module_xml.elementsByTagName("dependency")
                i = 0
                while i < len(depend_node):
                    dependencias[i] = depend_node.item(i).toElement().text()
                    i += 1
        else:
            if not isinstance(file_, str):
                raise Exception("data must be str, not bytes!!")
            file_array = file_.split("\n")
            modulo = self.get_value(file_array[0])
            descripcion = self.get_value(file_array[1])
            area = self.get_value(file_array[2]) or ""
            area_description = self.get_value(file_array[3])
            version = self.get_value(file_array[4])
            icon_name = self.get_value(file_array[5])

        descripcion = qsa.qt_translate_noop(descripcion or "", fichero.path or "", modulo or "")
        area_description = qsa.qt_translate_noop(
            area_description or "", fichero.path or "", modulo or ""
        )
        icon_file = qsa.File(qsa.ustr(fichero.path, "/", icon_name))
        icon_file.open(qsa.File.ReadOnly)
        icono = icon_file.read()
        icon_file.close()

        if not util.sqlSelect("flareas", "idarea", qsa.ustr("idarea = '", area, "'")):
            if not util.sqlInsert(
                "flareas", "idarea,descripcion", qsa.ustr(area, ",", area_description)
            ):
                qsa.MessageBox.warning(
                    util.translate("scripts", "Error al crear el área:\n") + area,
                    qsa.MessageBox.Ok,
                    qsa.MessageBox.NoButton,
                )
                return False
        recargar = util.sqlSelect("flmodules", "idmodulo", qsa.ustr("idmodulo = '", modulo, "'"))
        modules_cursor = qsa.FLSqlCursor("flmodules")
        if recargar:
            # WITH_START
            modules_cursor.select(qsa.ustr("idmodulo = '", modulo, "'"))
            modules_cursor.first()
            modules_cursor.setModeAccess(modules_cursor.Edit)
            # WITH_END

        else:
            modules_cursor.setModeAccess(modules_cursor.Insert)

        # WITH_START
        modules_cursor.refreshBuffer()
        modules_cursor.setValueBuffer("idmodulo", modulo)
        modules_cursor.setValueBuffer("descripcion", descripcion)
        modules_cursor.setValueBuffer("idarea", area)
        modules_cursor.setValueBuffer("version", version)
        modules_cursor.setValueBuffer("icono", icono)
        modules_cursor.commitBuffer()
        # WITH_END
        # curSeleccion = qsa.FLSqlCursor(u"flmodules")
        modules_cursor.setMainFilter(qsa.ustr("idmodulo = '", modulo, "'"))
        modules_cursor.editRecord(False)
        qsa.from_project("formRecordflmodules").load_from_disk(qsa.ustr(fichero.path, "/"), False)
        qsa.from_project("formRecordflmodules").accept()
        setting = "scripts/sys/modLastModule_%s" % qsa.sys.nameBD()
        nombre_fichero = "%s" % os.path.abspath(nombre_fichero)
        qsa.util.writeSettingEntry(setting, nombre_fichero)
        qsa.sys.processEvents()

        return True

    def version_compare(self, ver_1: str = "", ver_2: str = "") -> int:
        """Compare versions."""

        if ver_1 and ver_2:
            list_1 = ver_1.split(".")
            list_2 = ver_2.split(".")

            for num, item in enumerate(list_1):
                if qsa.parseInt(item) > qsa.parseInt(list_2[num]):
                    return 1
                if qsa.parseInt(item) < qsa.parseInt(list_2[num]):
                    return 2
        return 0

    def get_value(self, linea: str) -> str:
        """Return value."""
        return linea



# -*- coding: utf-8 -*-
"""
Module for PNSqlDrivers class.
"""

import importlib
import sys
import os

from pineboolib.core.utils import logging, utils_base
from pineboolib.core.utils.singleton import Singleton

from typing import Dict, Any, List, TYPE_CHECKING

if TYPE_CHECKING:
    from pineboolib.interfaces import isqldriver

LOGGER = logging.get_logger(__name__)


class PNSqlDriversManager(object, metaclass=Singleton):
    """
    PNSqlDriversManager class.

    Manage the different available sql drivers.
    """

    _driver: "isqldriver.ISqlDriver"
    _default_driver_name: str
    _drivers_dict: Dict[str, str]
    _driver_defaultr_port: Dict[str, int]
    _desktop_file: Dict[str, bool]
    # _only_pure_python = None

    def __init__(self, _DGI: Any = None) -> None:
        """Collect the information of the available cursors."""

        # self._only_pure_python = is_deployed()

        self._drivers_dict = {}
        self._driver_defaultr_port = {}
        self._desktop_file = {}

        dir_list = [
            file
            for file in os.listdir(utils_base.filedir("plugins/sql"))
            if not file[0] == "_" and file.find(".py") > -1
        ]
        for item in dir_list:
            file_name = item[: item.find(".py")]
            try:
                mod_ = importlib.import_module("pineboolib.plugins.sql.%s" % file_name)
            except ModuleNotFoundError:
                LOGGER.debug("Error trying to load driver %s", file_name, exc_info=True)
                continue
            except Exception:
                LOGGER.exception("Unexpected error loading driver %s", file_name)
                continue

            if getattr(mod_, file_name.upper(), None) is None:
                continue

            _driver = getattr(mod_, file_name.upper())()
            if _driver.pure_python() or _driver.safe_load():
                self._drivers_dict[file_name] = _driver.alias_
                self._driver_defaultr_port[_driver.alias_] = _driver.default_port
                # self._desktop_file[_driver.alias_] = _driver.desktopFile()

        self._defautl_driver_name = "FLsqlite"

    def loadDriver(self, driver_name: str) -> bool:
        """
        Load an sql driver specified by name.

        This driver is stored in the internal variable _driver.
        @param driver_name =  Sql driver name.
        @return True or False.
        """

        if not driver_name:
            return False

        # FIXES para cuando llamamos al driver con el nombre tradicional de Abanq/Eneboo
        if driver_name == "postgresql":
            driver_name = "flqpsql"

        module_path = "pineboolib.plugins.sql.%s" % driver_name.lower()
        module_obj = (
            importlib.reload(sys.modules[module_path])
            if module_path in sys.modules
            else importlib.import_module(module_path)
        )
        self._driver = getattr(module_obj, driver_name.upper())()

        if self.driver():
            # self.driverName = driverName
            LOGGER.debug("Driver %s v%s", self.driver().driverName(), self.driver().version())
            return True
        else:
            return False

    def nameToAlias(self, name: str) -> str:
        """
        Return the alias of a driver from the name.

        @param name =  Driver name.
        @return Alias or None.
        """

        name = name.lower()
        if name in self._drivers_dict.keys():
            return self._drivers_dict[name]

        raise Exception("No driver found matching name!")

    def aliasToName(self, alias: str = "") -> str:
        """
        Return the alias of a controller from its name.

        @param alias =  Alias ​​with which the controller is known.
        @return Driver name or None.
        """
        if not alias:
            return self._defautl_driver_name

        for key, value in self._drivers_dict.items():
            if value == alias:
                return key

        raise Exception("No driver found matching alias!")

    def port(self, alias: str) -> str:
        """
        Return the default port of an sql driver.

        @param alias. Driver Alias.
        @return Default port or '0'.
        """
        for k, value in self._driver_defaultr_port.items():
            if k == alias:
                return "%s" % value

        return "0"

    def isDesktopFile(self, alias: str) -> bool:
        """
        Indicate if the BD to which the controller is connected is desktop.

        @param alias. Driver Alias.
        @return True or False.
        """
        for k, value in self._desktop_file.items():
            if k == alias:
                return value

        raise Exception("Alias not found in list!")

    def aliasList(self) -> List[str]:
        """
        List the aliases of the available drivers.

        @return List of available aliases.
        """

        list = []
        for key, value in self._drivers_dict.items():
            list.append(value)

        return list

    def driver(self) -> "isqldriver.ISqlDriver":
        """
        Link to the used controller.

        @return Driver instance.
        """

        return self._driver

    """
    Informa del nombre del controlador
    @return Nombre del controlador
    """

    def driverName(self) -> str:
        """
        Indicate the name of the activated driver.
        """

        if self._driver is None:
            raise Exception("No sql driver selected!")

        return self._driver.name_

    # def __getattr__(self, attr_name):
    #    """
    #    Return an attribute of the sql driver, if it is not found.

    #    @param attr_name: Attribute name.
    #    """
    #    return getattr(self._driver, attr_name)

    def defaultDriverName(self) -> str:
        """
        Return the name of the default sql driver.

        @return Default driver name.
        """
        return self._defautl_driver_name



"""Test_flcodbar module."""

import unittest
from pineboolib.fllegacy import flcodbar


class TestFLCodBar(unittest.TestCase):
    """TestFLCodBar Class."""

    def test_basic(self) -> None:
        """Test basic."""

        cod_bar = flcodbar.FLCodBar("12345678")

        self.assertEqual(cod_bar.value(), "12345678")
        self.assertEqual(cod_bar.type_(), 13)
        cod_bar.setMargin(10)
        self.assertEqual(cod_bar.margin(), 10)
        cod_bar.setScale(1.0)
        self.assertEqual(cod_bar.scale(), 1.0)
        cod_bar.setCut(2.0)
        self.assertEqual(cod_bar.cut(), 2.0)
        cod_bar.setText("TEXTO")
        self.assertEqual(cod_bar.text(), "TEXTO")
        cod_bar.setRotation(10)
        self.assertEqual(cod_bar.rotation(), 10)
        self.assertEqual(cod_bar.fg().value, 2)
        self.assertEqual(cod_bar.bg().value, 3)
        cod_bar.setCaption("9876543210")
        self.assertEqual(cod_bar.caption(), "9876543210")
        cod_bar.setValue("010101010101")
        self.assertEqual(cod_bar.value(), "010101010101")
        self.assertFalse(cod_bar.validBarcode())
        cod_bar._createBarcode()
        self.assertTrue(cod_bar.validBarcode())
        cod_bar.fillDefault()
        self.assertEqual(cod_bar.typeToName(cod_bar.type_()), "Code39")
        self.assertEqual(cod_bar.nameToType("Code39"), 12)
        bar2 = flcodbar.FLCodBar(cod_bar)
        self.assertEqual(cod_bar.typeToName(bar2.type_()), "Code39")



"""Test flfiles module."""


import unittest
from pineboolib.loader.main import init_testing, finish_testing
from pineboolib import logging, application
from pineboolib.system_module.scripts.tests import fixture_path
from pineboolib.core.utils import utils_base

import os

LOGGER = logging.get_logger("eneboo_%s" % __name__)


class TestFlFiles(unittest.TestCase):
    """TestFlfiles class."""

    @classmethod
    def setUpClass(cls) -> None:
        """Ensure pineboo is initialized for testing."""
        utils_base.FORCE_DESKTOP = True
        init_testing()

    def test_basic(self) -> None:
        """Test load files into Database."""
        from pineboolib.qsa import qsa
        from pineboolib.plugins.mainform import eneboo

        application.PROJECT.main_window = eneboo.MainForm()
        application.PROJECT.main_window.initScript()

        path = fixture_path("principal.eneboopkg")
        self.assertTrue(os.path.exists(path))
        self.assertTrue(qsa.sys.loadModules(path, False))
        qsa.sys.reinit()

        script = qsa.from_project("formRecordflfiles")
        self.assertTrue(script)
        script.cursor().first()
        func_ = script.init
        self.assertTrue(func_)
        func_()

    def test_basic2(self) -> None:
        """Test basic 2."""
        from pineboolib.qsa import qsa

        session = qsa.thread_session_new()
        session.begin()
        file_class = qsa.orm_("flfiles")
        self.assertTrue(file_class)
        obj_ = file_class()
        obj_.nombre = "prueba.txt"
        obj_.idmodulo = "flfactppal"
        obj_.sha = ""
        self.assertTrue(obj_.save())
        session.commit()

    @classmethod
    def tearDownClass(cls) -> None:
        """Ensure test clear all data."""
        finish_testing()



"""Alembic tools module."""

from pineboolib.application.utils import path
from pineboolib import logging
from alembic import config, migration
import configparser
import os


from typing import List, Dict, Any, TYPE_CHECKING

LOGGER = logging.get_logger(__name__)

if TYPE_CHECKING:
    from pineboolib.interfaces import iconnection, itablemetadata


class Migration:
    """Migration class."""

    _alembic_folder: str
    _current_dir: str
    _table_name: str

    def __init__(self, conn: "iconnection.IConnection"):
        """Initialize."""

        self._conn = conn
        self._current_dir = os.getcwd()
        self._alembic_folder = os.path.join(path._dir("cache"), conn.DBName(), "migrations")

    def upgrade(self, metadata: "itablemetadata.ITableMetaData") -> bool:
        """Launch migration."""

        if not metadata.isQuery():
            self.create()

            # self.update_env()
            file_name = self.buildFile(metadata.name())
            if file_name:
                changes_dict = self._conn.driver().calculateChanges(metadata)

                if changes_dict and self.applyChangesInFile(file_name, changes_dict):
                    LOGGER.warning("APLICANDO CAMBIOS!!")
                    config.main(argv=["upgrade", "head"])
                else:
                    LOGGER.warning("Eliminando %s" % file_name)
                    os.remove(file_name)
            else:
                LOGGER.warning("no se encuentra el fichero de revisión a modificar")

            os.chdir(self._current_dir)

        return True

    def applyChangesInFile(self, file_name: str, changes_dict: Dict[str, List[Any]]):
        """Apply changes in file."""
        try:
            file_ = open(file_name, "r", encoding="UTF-8")
            data: str = file_.read()
            file_.close()

            def_upgrade = (
                "def upgrade() -> None:\n\n    %s" % (("\n    ").join(changes_dict["upgrade"]))
                if changes_dict["upgrade"]
                else None
            )

            def_downgrade = (
                "def downgrade() -> None:\n\n    %s" % (("\n    ").join(changes_dict["downgrade"]))
                if changes_dict["downgrade"]
                else None
            )

            if def_upgrade:
                data = data.replace("def upgrade() -> None:\n    pass", def_upgrade)
            if def_downgrade:
                data = data.replace("def downgrade() -> None:\n    pass", def_downgrade)

            file_ = open(file_name, "w", encoding="UTF-8")
            file_.write(data)
            file_.close()

        except Exception as error:
            LOGGER.warning("applyChangesInFile: %s (%s)" % (file_name, str(error)))
            return False

        return True

    def buildFile(self, table_name: str) -> str:
        """Build file for migration."""
        result = ""
        try:
            os.chdir(self._alembic_folder)
            config.main(argv=["revision", "-m", "alter_table_%s" % table_name])
            result = self.getNewFileName()
        except Exception as error:
            LOGGER.warning("Error building file: %s" % (str(error)))

        return result

    def getNewFileName(self) -> str:
        """Return new file name."""

        current_revision = self.getCurrentRev()
        if current_revision:
            current_revision = "'%s'" % current_revision

        folder_path = os.path.join(self._alembic_folder, "alembic", "versions")
        last = None
        for file_name in os.listdir(folder_path):
            if file_name.startswith("_"):
                continue

            file_path = os.path.join(folder_path, file_name)
            file_time = os.path.getctime(file_path)

            if last is None:
                last = [file_time, file_path]
                continue

            if file_time > last[0]:  # type: ignore [unreachable]
                last = [file_time, file_path]

        return "" if last is None else str(last[1])

    def getCurrentRev(self):
        """Return current revision stored in database."""

        context = migration.MigrationContext.configure(self._conn.connection())
        return context.get_current_revision()

    def update_enviroment(self):
        """Update enviroment."""

        pass

    def create(self):
        """Create structure."""

        if not os.path.exists(self._alembic_folder):
            # borrar alembic_version
            os.mkdir(self._alembic_folder)
            os.chdir(self._alembic_folder)

            config.main(argv=["init", "alembic"])

            alembic_ini = os.path.join(self._alembic_folder, "alembic.ini")

            config_ = configparser.ConfigParser()
            config_.read(alembic_ini)
            config_["alembic"]["script_location"] = "alembic"
            config_["alembic"]["sqlalchemy.url"] = self._conn.resolve_dsn()

            with open(alembic_ini, "w") as configfile:  # save
                config_.write(configfile)

            os.chdir(self._current_dir)



"""Test_date module."""

import unittest
import datetime


class TestDate(unittest.TestCase):
    """TestDate Class."""

    def test_basic(self) -> None:
        """Test Date class."""

        from pineboolib.application.qsatypes import date

        date_ = date.Date("2019-11-03")
        self.assertEqual(date_.toString(), "2019-11-03T00:00:00")
        self.assertEqual(date_.toString("yyyy-MM-dd"), "2019-11-03")
        self.assertEqual(date_.toString("MM:yyyy-dd"), "11:2019-03")
        self.assertEqual(date_.getTime(), 20191103000000)
        self.assertEqual(date_.getYear(), 2019)
        self.assertEqual(date_.getMonth(), 11)
        self.assertEqual(date_.getDay(), 3)
        date_.setDay(26)
        self.assertEqual(date_.toString(), "2019-11-26T00:00:00")
        self.assertEqual(date_.getDay(), 26)
        self.assertEqual(date_.addDays(3).toString("yyyy-MM-dd"), "2019-11-29")
        self.assertEqual(date_.addMonths(-2).toString("yyyy-MM-dd"), "2019-09-26")
        self.assertEqual(date_.addYears(1).toString("yyyy-MM-dd"), "2020-11-26")

        date2_ = date.Date("2020-01-31T12:10:59")
        self.assertEqual(date2_.getHours(), 12)
        date2_.setYear("2021")
        date2_.setMonth("12")
        date2_.setDay(16)
        self.assertEqual(date2_.getHours(), 12)
        self.assertEqual(date2_.getMinutes(), 10)
        self.assertEqual(date2_.getSeconds(), 59)
        self.assertEqual(date2_.getMilliseconds(), 0)

        self.assertEqual(date2_.getYear(), 2021)
        self.assertTrue(date_ < date2_)
        self.assertFalse(date_ == date2_)
        self.assertTrue(date_ != date2_)
        date2_.setDate(14)
        self.assertEqual(date2_.getDay(), 14)

        date3_ = date2_.parse("2019-06-02T00:00:00")
        self.assertEqual(
            datetime.datetime.strptime("2019-06-02", "%Y-%m-%d").timestamp() * 1000, date3_
        )



"""
Basic exception classes.

Just a few classes that inherit from Exception for those cases where
Python does not provide a sensible built-in exception.
"""


class CodeDoesNotBelongHereException(Exception):
    """
    The code calling here is just wrong. This object should be unaware of this concept. Please look for other places to code this.

    Please don't code anything related to fllegacy/dgi here.
    """


class NotConnectedError(Exception):
    """Code expected a connection to be made already but it wasn't."""


class ForbiddenError(Exception):
    """Action attempted is not allowed."""


class QSAError(Exception):
    """QSA script error."""


class TransactionOpenedException(Exception):
    """Transactions opened error."""



"""QBytearray module."""
# -*- coding: utf-8 -*-

from PyQt6 import QtCore  # type: ignore[import]
from typing import Union


class QByteArray(QtCore.QByteArray):
    """QByteArray class."""

    def __init__(self, *args) -> None:
        """Inicialize."""

        if len(args) == 1 and isinstance(args[0], int):  # QByteArray(int)
            super().__init__()
        else:
            super().__init__(*args)

    def set(self, pos: int, _ch: Union[str, int]) -> None:
        """Set a char into a position."""
        _ch = _ch if isinstance(_ch, str) else chr(_ch)
        super().insert(pos, _ch.encode())

    def get(self, pos: int):
        """Get a char number from a position."""
        return self.data()[pos]

    def fromBase64(self, *args) -> bytes:  # type: ignore[override] # noqa : F821
        """Return a decoded base64 value."""
        if args:
            return super().fromBase64(*args).data()
        else:
            import base64

            return base64.b64decode(self.data())

    def sha1(self) -> str:
        """Return sha1."""
        hash = QtCore.QCryptographicHash(QtCore.QCryptographicHash.Algorithm.Sha1)
        hash.addData(self.data())
        return hash.result().toHex().data().decode("utf-8").upper()

    def setString(self, val: str) -> None:
        """Set string to QByteArray."""
        self.append(val.encode())

    def getString(self) -> str:
        """Return string value format."""
        return self.data().decode("utf-8").upper()

    string = property(getString, setString)



# -*- coding: utf-8 -*-
"""
QSA Emulation module.

This file should be imported at top of QS converted files.
"""

import re  # noqa: F401

from pineboolib.core.utils.utils_base import ustr, filedir  # noqa: F401
from pineboolib.application.types import QString, String  # noqa: F401
from pineboolib.application.types import boolean as Boolean  # noqa: F401
from pineboolib.application.types import function as Function  # noqa: F401
from pineboolib.application.types import object_ as Object  # noqa: F401

from pineboolib.application.types import File, Dir, Array, Date, AttributeDict  # noqa: F401
from pineboolib.application.types import FileStatic, DirStatic  # noqa: F401

from pineboolib.qsa.input import Input  # noqa: F401
from pineboolib.qsa.utils import reg_exp as RegExp  # noqa: F401
from pineboolib.qsa.utils import parse_float as parseFloat  # noqa: F401
from pineboolib.qsa.utils import to_json as toJson  # noqa: F401
from pineboolib.qsa.utils import parse_string as parseString  # noqa: F401
from pineboolib.qsa.utils import parse_int as parseInt  # noqa: F401
from pineboolib.qsa.utils import start_timer as startTimer  # noqa: F401
from pineboolib.qsa.utils import kill_timer as killTimer  # noqa: F401
from pineboolib.qsa.utils import kill_timers as killTimers  # noqa: F401
from pineboolib.qsa.utils import is_nan as isNaN  # noqa: F401
from pineboolib.qsa.utils import debug, isnan, replace, length, text  # noqa: F401
from pineboolib.qsa.utils import format_exc, Sort, splice, typeof_  # noqa: F401
from pineboolib.qsa.utils import Switch as switch  # noqa: F401
from pineboolib.qsa.utils import QsaRegExp as qsaRegExp  # noqa: F401
from pineboolib.qsa.utils import (  # noqa: F401
    ws_channel_send,
    thread,
    user_id,
    session_atomic,
    session,
    _super,
)
from pineboolib.qsa.utils import (  # noqa: F401
    thread_session_new,
    thread_session_current,
    thread_session_free,
)
from pineboolib.qsa.utils import (  # noqa: F401
    pool_status,
    set_user_id,
    memory_status,
    qt_translate_noop,
)
from pineboolib.qsa.utils import ws_channel_send_type, is_valid_session  # noqa: F401
from pineboolib.qsa.decorators import atomic, serialize  # noqa: F401

from pineboolib.qsa.pncontrolsfactory import from_project, orm_, Application  # noqa: F401


# QT
from pineboolib.qsa.pncontrolsfactory import QS_PROJECT, QSA_SYS, MATH, NUMBER_ATT
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    QComboBox,
    QTable,
    QLayoutWidget,
    QToolButton,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    QTabWidget,
    QLabel,
    QGroupBox,
    QListView,
    QImage,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    QTextEdit,
    QLineEdit,
    QDateEdit,
    QTimeEdit,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    QCheckBox,
    QWidget,
    QMessageBox,
    QDialog,
    QDateTime,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    QVBoxLayout,
    QHBoxLayout,
    QFrame,
    QMainWindow,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    QMenu,
    QToolBar,
    QAction,
    QDataView,
    QByteArray,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    QMdiArea,
    QEventLoop,
    QActionGroup,
    QInputDialog,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    QApplication,
    QStyleFactory,
    QFontDialog,
    QTextStream,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    QMdiSubWindow,
    QSizePolicy,
    QProgressDialog,
)
from pineboolib.qsa.pncontrolsfactory import QFileDialog, QTreeWidget, QTreeWidgetItem  # noqa: F401
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    QTreeWidgetItemIterator,
    QListWidgetItem,
    QObject,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    QListViewWidget,
    QSignalMapper,
    QPainter,
    QBrush,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    QKeySequence,
    QIcon,
    QColor,
    QDomDocument,
    QIconSet,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    QPushButton,
    QSpinBox,
    QRadioButton,
    QPixmap,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    QButtonGroup,
    QToolBox,
    QSize,
    QDockWidget,
    QDir,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    QPopupMenu,
    QBuffer,
    QHButtonGroup,
    QVButtonGroup,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    QHttp,
    QHttpResponseHeader,
    QHttpRequestHeader,
)

# FL
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    FLDomDocument,
    FLDomElement,
    FLDomNode,
    FLFastCgi,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    FLDomNodeList,
    FLLineEdit,
    FLTimeEdit,
    FLDateEdit,
)
from pineboolib.qsa.pncontrolsfactory import FLPixmapView, FLDataTable, FLCheckBox  # noqa: F401
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    FLTextEditOutput,
    FLSpinBox,
    FLTableDB,
    FLFieldDB,
)
from pineboolib.qsa.pncontrolsfactory import FLFormDB, FLFormRecordDB, FLFormSearchDB  # noqa: F401
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    FLDoubleValidator,
    FLIntValidator,
    FLUIntValidator,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    FLCodBar,
    FLWidget,
    FLWorkSpace,
    FLPosPrinter,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    FLSqlQuery,
    FLSqlCursor,
    FLNetwork,
    FLSerialPort,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    FLApplication,
    FLVar,
    FLSmtpClient,
    FLTable,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    FLListViewItem,
    FLReportViewer,
    FLUtil,
    FLSettings,
)
from pineboolib.qsa.pncontrolsfactory import FLScriptEditor, FLReportEngine  # noqa: F401
from pineboolib.qsa.pncontrolsfactory import FLJasperEngine, FLJasperViewer  # noqa: F401

# QSA
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    FileDialog,
    Color,
    Label,
    Line,
    CheckBox,
    Dialog,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    ComboBox,
    TextEdit,
    LineEdit,
    MessageBox,
    RadioButton,
)
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    GroupBox,
    SpinBox,
    NumberEdit,
    DateEdit,
    TimeEdit,
)
from pineboolib.qsa.pncontrolsfactory import Picture, Rect, Size, Pixmap, Font  # noqa: F401


# AQS
from pineboolib.qsa.pncontrolsfactory import AQS, AQUnpacker, AQSettings, AQSqlQuery  # noqa: F401
from pineboolib.qsa.pncontrolsfactory import AQSqlCursor, AQUtil, AQSql, AQSmtpClient  # noqa: F401
from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
    AQSignalMapper,
    AQSSProject,
    AQObjectQueryList,
)
from pineboolib.qsa.pncontrolsfactory import AQSButtonGroup  # noqa: F401

from pineboolib.core.utils.utils_base import is_deployed as __is_deployed
from pineboolib.core.utils.utils_base import is_library as __is_library

if not __is_deployed() and not __is_library():
    # FIXME: No module named 'xml.sax.expatreader' in deploy
    from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
        AQOdsGenerator,
        AQOdsSpreadSheet,
        AQOdsSheet,
    )
    from pineboolib.qsa.pncontrolsfactory import (  # noqa: F401
        AQOdsRow,
        AQOdsColor,
        AQOdsStyle,
        AQOdsImage,
    )

from pineboolib.qsa.pncontrolsfactory import AQBoolFlagState, AQBoolFlagStateList  # noqa: F401


from pineboolib.qsa.pncontrolsfactory import FormDBWidget, ObjectClass  # noqa: F401
from pineboolib.application.process import Process, ProcessStatic  # noqa: F401
from pineboolib.qsa.pncontrolsfactory import SysType, System  # noqa: F401
from pineboolib.qsa.pncontrolsfactory import AQ_APP as aqApp  # noqa: F401
from pineboolib.qsa.pncontrolsfactory import ORM_MANAGER as orm  # noqa: F401
from pineboolib.qsa.pncontrolsfactory import CLASS_MANAGER as class_  # noqa: F401
from pineboolib.qsa.pncontrolsfactory import XmlDigest, PdfDigest  # noqa: F401
from pineboolib.qsa.pncontrolsfactory import PdfQr  # noqa: F401
from pineboolib.qsa.pncontrolsfactory import require  # noqa: F401

QSProject = QS_PROJECT
sys = QSA_SYS
Math = MATH
Number = NUMBER_ATT


QFile = File
util = FLUtil  # pylint: disable=invalid-name
print_ = print


undefined = None  # pylint: disable=invalid-name
LogText = 0  # pylint: disable=invalid-name
RichText = 1  # pylint: disable=invalid-name
